/******************************************************************************
*                      www.shotech.de                                         *
*                                                                             *
*******************************************************************************
*  $Source: /home/CVS/                      ,v $
*-----------------------------------------------------------------------------*
*  Datum der 1. Version  :  03.07.2003
*  Geraete Bezeichnung   :                              
*-----------------------------------------------------------------------------*
*- $Id:                                         Exp $
*-----------------------------------------------------------------------------*
*
*       Headerfile
*       ----------
*       LCD-Driver-STE2002
*
******************************************************************************/

#ifndef _STE2002_H_
#define _STE2002_H_



//--- Includes -----------------------------------------------------------------



//--- Defines ------------------------------------------------------------------

//- Page Number
#define DISPLAY_PAGE0       (u8)0x00 //0b00000000  //- default
#define DISPLAY_PAGE1       (u8)0x01 //0b00000001
#define DISPLAY_PAGE2       (u8)0x02 //0b00000010
#define DISPLAY_PAGE3       (u8)0x03 //0b00000011

//- Funktion Set
#define DISPLAY_FUNC_SET    (u8)0x20 //0b00100000
#define DISPLAY_POWER_ON    (u8)0x00 //0b00000000
#define DISPLAY_POWER_OFF   (u8)0x04 //0b00000100  //- default
#define DISPLAY_SET_MX      (u8)0x10 //0b00010000
#define DISPLAY_SET_MY      (u8)0x08 //0b00001000

//- Display Mode
#define DISPLAY_CONFIG      (u8)0x08 //0b00001000
#define DISPLAY_BLANK       (u8)0x00 //0b00000000  //- default
#define DISPLAY_SEG_ON      (u8)0x01 //0b00000001
#define DISPLAY_NORMAL      (u8)0x04 //0b00000100
#define DISPLAY_INVERSE     (u8)0x05 //0b00000101

//- Display FRAME RATE CONTROL
#define DISPLAY_SET_FRAME   (u8)0x04 //0b00000100
#define DISPLAY_FRAME_65    (u8)0x00 //0b00000000  //- LCD LCD-EM-3737-F-BACK
#define DISPLAY_FRAME_70    (u8)0x01 //0b00000001
#define DISPLAY_FRAME_75    (u8)0x02 //0b00000010  //- default
#define DISPLAY_FRAME_80    (u8)0x03 //0b00000011

//- VLCD RANGE SELECTION
#define DISPLAY_SET_VLCD    (u8)0x04 //0b00000100
#define DISPLAY_2_94V       (u8)0x00 //0b00000000
#define DISPLAY_6_78V       (u8)0x01 //0b00000001  //- LCD LCD-EM-3737-F-BACK
#define DISPLAY_10_62V      (u8)0x02 //0b00000010
#define DISPLAY_NOT_USED    (u8)0x03 //0b00000011

//- MULTIPLEXING RATIO
#define DISPLAY_SET_MUX     (u8)0x08 //0b00001000
#define DISPLAY_MUX_49      (u8)0x00 //0b00000000  //- LCD-EM-3737-F-BACK
#define DISPLAY_MUX_65      (u8)0x01 //0b00000001  //- default
#define DISPLAY_MUX_81      (u8)0x02 //0b00000010
#define DISPLAY_MUX_NOT     (u8)0x03 //0b00000011

//- TEMPERATURE COEFFICIENT
#define DISPLAY_SET_T       (u8)0x08
#define DISPLAY_TEMP_T0     (u8)0x00        //- default
#define DISPLAY_TEMP_T1     (u8)0x01
#define DISPLAY_TEMP_T2     (u8)0x02
#define DISPLAY_TEMP_T3     (u8)0x03
#define DISPLAY_TEMP_T4     (u8)0x04
#define DISPLAY_TEMP_T5     (u8)0x05
#define DISPLAY_TEMP_T6     (u8)0x06
#define DISPLAY_TEMP_T7     (u8)0x07

#define DISPLAY_SET_TC      (u8)0x04
#define DISPLAY_TEMP_TC0    (u8)0x00        //- default
#define DISPLAY_TEMP_TC1    (u8)0x01
#define DISPLAY_TEMP_TC2    (u8)0x02
#define DISPLAY_TEMP_TC3    (u8)0x03

//- CHARGE PUMP MULTIPLICATION FACTOR
#define DISPLAY_SET_CP      (u8)0x10
#define DISPLAY_PUMP_X2     (u8)0x00        //- default
#define DISPLAY_PUMP_X3     (u8)0x01        //- 3 * 3,3 Volt = 9,9 Volt VLCD
#define DISPLAY_PUMP_X4     (u8)0x02
#define DISPLAY_PUMP_X5     (u8)0x03
#define DISPLAY_PUMP_X6     (u8)0x04
#define DISPLAY_PUMP_N1     (u8)0x05        //- not used
#define DISPLAY_PUMP_N2     (u8)0x06        //- not used
#define DISPLAY_PUMP_AU     (u8)0x07        //- automatic


//- DATA FORMAT
#define DISPLAY_DATA_FORMAT (u8)0x08 // Data Format
#define DISPLAY_SET_DO      (u8)0x04 // DO

//- BIAS RATIO
#define DISPLAY_BIAS_SET    (u8)0x10
#define DISPLAY_BIAS_7      (u8)0x00        //- default
#define DISPLAY_BIAS_6      (u8)0x01
#define DISPLAY_BIAS_5      (u8)0x02
#define DISPLAY_BIAS_4      (u8)0x03        //- fuer LCD-EM-3737-F-BACK
#define DISPLAY_BIAS_3      (u8)0x04
#define DISPLAY_BIAS_2      (u8)0x05
#define DISPLAY_BIAS_1      (u8)0x06
#define DISPLAY_BIAS_0      (u8)0x07

//- Y CARRIAGE RETURN REGISTER
#define DISPLAY_CAR_REG1    (u8)0x01
#define DISPLAY_CAR_REG2    (u8)0x02
#define DISPLAY_CAR_REG3    (u8)0x03
#define DISPLAY_CAR_REG4    (u8)0x04
#define DISPLAY_CAR_REG5    (u8)0x05
#define DISPLAY_CAR_REG6    (u8)0x06
#define DISPLAY_CAR_REG7    (u8)0x07
#define DISPLAY_CAR_REG8    (u8)0x08        //- default
#define DISPLAY_CAR_REG9    (u8)0x09
#define DISPLAY_CAR_REG10   (u8)0x0A
#define DISPLAY_CAR_REG11   (u8)0x0B
#define DISPLAY_CAR_REG12   (u8)0x0C  

//- PARTIAL DISPLAY CONFIGURATION
#define DISPLAY_PART_0_8    (u8)0x00        //- default
#define DISPLAY_PART_8_0    (u8)0x01
#define DISPLAY_PART_8_8    (u8)0x02
#define DISPLAY_PART_0_16   (u8)0x03
#define DISPLAY_PART_16_0   (u8)0x04
#define DISPLAY_PART_8_16   (u8)0x05
#define DISPLAY_PART_16_8   (u8)0x06
#define DISPLAY_PART_16_16  (u8)0x07

//- SET RAM X SET RAM Y
#define DISPLAY_SET_RAM_Y   (u8)0x40 //0b01000000  //- max 15
#define DISPLAY_SET_RAM_X   (u8)0x80 //0b10000000  //- max 127

#define DISPLAY_MAX_RAM_Y   48          //- 48  Pixel
#define DISPLAY_MAX_RAM_X   128         //- 128 Pixel

#define DISPLAY_RAM_Y_BYTE  DISPLAY_MAX_RAM_Y / 8
#define DISPLAY_RAM_X_BYTE  DISPLAY_MAX_RAM_X / 8

    
//- Explanations
#define DIR_SCROLL_ON_DOWN  0
#define DIR_SCROLL_ON_UP    1


#define DISPLAY_COMMAND     (u8)0x80 //- Controlbyte Command
#define DISPLAY_DATA        (u8)0x40 //0b01000000 //- Controlbyte Data

#define DISPLAY_CLEAR       (u8)0x01 //0b00000001 //- Memory Blank
#define DISPLAY_FILL        (u8)0x01 //0b00000001 //- Checker Board

#define DISPLAY_SET_VOP     (u8)0x80 //0b10000000

#define PARTIAL_DISABLE     (u8)0x02 //0b00000010
#define DISPLAY_VOP_V       32         //- Vlcd = ( 6,78V + 32 * 0,0303 )
                                       //  VLCD = 7,8V

#define DISPLAY_ROWS          6 // Anzahl der Zeilen (je 8-Pixel hoch)
#define DISPLAY_COLS        128 // Anzahl der Spalten (je 1-Pixel breit)

#define DISPLAY_FILL_COUNT  768 // Anzahl der Bytes, die bentigt werden,
                                // um das gesamte Display zu beschreiben
                                
#define DISPLAY_HEAD_COUNT    5 // Anzahl der Bytes, die bentigt werden,
                                // um eine Befehlssequenz vor den
                                // Displaydaten zu bertragen

// Gre der I2C-Displaybuffers
#define I2C_DISPLAY_BUFFER_SIZE   (DISPLAY_HEAD_COUNT + DISPLAY_FILL_COUNT)




//- Funktionen
/*
SETUP NORMAL DISPLAY MODE CONFIGURATION
SET Driver in Power Down(PD=1)
SET Driver in Normal Display Mode (PE=0)
END OF NORMAL DISPLAY MODE CONFIG.
SET PRS[1:0], Vop[6:0], BS[2:0], CP[2:0], FR[1:0],
TC, M[1:0] for Normal Display Operation
Switch "ON" Booster and Display Control Logic
(PD=0)
*/  





//--- Enumerations -------------------------------------------------------------

// Enumeration fr die verfgbaren Fonts
enum EFonts 
{
  FONT_8x16,     // Font 8x16
  FONT_14x24,    // Font 13x24 nur Ziffern 0-9,-,l,m,n,,  enthalten
  FONT_MAX       // letzter Eintrag in die Enumeration
};



enum EDisplayPower
{
	POWER_OFF,
	POWER_ON
};

//--- Structures ---------------------------------------------------------------


// Im I2C-Displaybuffer wird zunchst das gesamte Bild aufgebaut, bevor dieser an
// das Display gesendet wird, um den gesamten Bildschirminhalt neu zu schreiben.
//
// Organisation des I2C-Displaybuffers:
//
// Die Werte von Index 0 bis 3 im I2C-Displaybuffer sind fr die Befehle zur
// X/Y-Positionierung (0/0) der ersten Schreibposition reserviert:
// sDisplayI2C.bData[0] = DISPLAY_COMMAND;
// sDisplayI2C.bData[1] = DISPLAY_SET_RAM_Y;
// sDisplayI2C.bData[2] = DISPLAY_COMMAND;
// sDisplayI2C.bData[3] = DISPLAY_SET_RAM_X;
// sDisplayI2C.bData[4] = DISPLAY_DATA;
//
// Alle weiteren Werte ab Index 5 bis 772 im I2C-Displaybuffer reprsentieren
// die Pixeldaten, die auf das Display geschrieben werden:
// sDisplayI2C.bData[5]   = ... (Pixeldaten);
// sDisplayI2C.bData[...] = ... (Pixeldaten);
// sDisplayI2C.bData[772] = ... (Pixeldaten);
//
// In sDisplayI2C.wPosition steht die Position, ab welcher die nchsten
// Pixeldaten in sDisplayI2C.bData[] geschrieben werden 
//(sDisplayI2C.bData[sDisplayI2C.wPosition]).
//
struct SDisplayI2C
{
  u16 wPosition;                      // Schreibposition im Buffer
  u8  bData[I2C_DISPLAY_BUFFER_SIZE]; // Buffer
};





//--- Prototypes ---------------------------------------------------------------




//- die Initialisierungssequenz an das Display senden
u16 LcdInit(void);




//------------------------------------------------------------------------------

#endif // #ifndef _STE2002_H_



